@@ -2,8 +2,8 @@ package lang
 
 import (
 	"github.com/lmorg/murex/builtins/pipes/streams"
-	"github.com/lmorg/murex/lang/state"
 	"github.com/lmorg/murex/lang/ref"
+	"github.com/lmorg/murex/lang/state"
 )
 
 func compile(tree *AstNodes, parent *Process) (procs []Process, errNo int) {
@@ -21,6 +21,8 @@ func compile(tree *AstNodes, parent *Process) (procs []Process, errNo int) {
 		procs[i].State.Set(state.MemAllocated)
 		procs[i].Name.Set((*tree)[i].Name)
 		procs[i].IsMethod = (*tree)[i].Method
+		procs[i].OperatorLogicAnd = (*tree)[i].LogicAnd
+		procs[i].OperatorLogicOr = (*tree)[i].LogicOr
 		procs[i].Background.Set(parent.Background.Get())
 		procs[i].Parent = parent
 		procs[i].Scope = parent.Scope
@@ -34,6 +36,8 @@ func compile(tree *AstNodes, parent *Process) (procs []Process, errNo int) {
 		procs[i].Kill = func() {}
 		//procs[i].hasTerminated = make(chan bool, 1)
 		procs[i].PromptId = parent.PromptId
+		procs[i].CCEvent = parent.CCEvent
+		procs[i].CCExists = parent.CCExists
 
 		procs[i].FileRef = &ref.File{Source: parent.FileRef.Source}
 
@@ -85,6 +89,7 @@ func compile(tree *AstNodes, parent *Process) (procs []Process, errNo int) {
 		case (*tree)[i].NewChain:
 			// new chain
 			procs[i].Stdin = streams.NewStdin()
+			//procs[i].Stdin = new(null.Null)
 		}
 
 		// Define stdout / stderr interfaces:
