@@ -71,7 +71,7 @@ func execSource(source []rune, sourceRef *ref.Source) {
 }
 
 func defaultProfile() {
-	os.Stderr.WriteString("Loading default profile" + utils.NewLineString)
+	//os.Stderr.WriteString("Loading default profile" + utils.NewLineString)
 	source := defaults.DefaultMurexProfile()
 	ref := ref.History.AddSource("(builtin)", "source/builtin", []byte(string(source)))
 	execSource(defaults.DefaultMurexProfile(), ref)
