@@ -4,7 +4,8 @@ package consts
 
 const (
 	// NamedPipeProcName is the GoFunction name used for murex builtin that outputs from a named pipe
-	NamedPipeProcName = "(murex named pipe)"
+	//NamedPipeProcName = "(murex named pipe)"
+	NamedPipeProcName = "read-named-pipe"
 
 	// TestTableHeadings is the header line for the `table` test report format
 	TestTableHeadings = " Status  Definition Function                                           Line Col. Message"
