@@ -8,7 +8,14 @@ func (rl *Instance) getHintText() {
 		return
 	}
 
+	hint := rl.cacheHint.Get(rl.line)
+	if len(hint) > 0 {
+		rl.hintText = hint
+		return
+	}
+
 	rl.hintText = rl.HintText(rl.line, rl.pos)
+	rl.cacheHint.Append(rl.line, rl.hintText)
 }
 
 func (rl *Instance) writeHintText(resetCursorPos bool) {
@@ -28,6 +35,11 @@ func (rl *Instance) writeHintText(resetCursorPos bool) {
 		}
 	}
 
+	// fix bug https://github.com/lmorg/murex/issues/376
+	if rl.termWidth == 0 {
+		rl.termWidth = GetTermWidth()
+	}
+
 	// Determine how many lines hintText spans over
 	// (Currently there is no support for carridge returns / new lines)
 	hintLength := strLen(hintText)
@@ -39,9 +51,13 @@ func (rl *Instance) writeHintText(resetCursorPos bool) {
 
 	if rl.hintY > 3 {
 		rl.hintY = 3
-		hintText = hintText[:(rl.termWidth*3)-4] + "..."
+		//hintText = hintText[:(rl.termWidth*3)-4] + "..."
+		hintText = hintText[:(rl.termWidth*3)-2] + "…"
 	} else {
 		padding := (rl.hintY * rl.termWidth) - len(hintText)
+		if padding < 0 {
+			padding = 0
+		}
 		hintText += strings.Repeat(" ", padding)
 	}
 
